#!/usr/bin/env python3

import unittest


files = ['../examples/images/rotate.jpg',
         '../examples/images/rotate_2.jpg',
         '../examples/images/rotate_3.jpg']

hint_img = '../examples/images/grid_hint.jpg'
hint_text = 'Put the images in the correct way up'
        

try:
    from .abstract import AbstractTest

    files = [f[3:] for f in files]
    hint_img = hint_img[3:]

except ImportError:
    from abstract import AbstractTest







files_dict = {f'file_{e+1}': f for e, f in enumerate(files)}

checks = {'method' : 'rotatecaptcha'}



class RotateTest(AbstractTest):

    def test_single_file(self):
        
        sends = {'method': 'post', 'file': files[0], **checks}
        return self.send_return(sends, self.solver.rotate, files=files[0])



    def test_file_param(self):
        
        sends = {'method': 'post',
                 'files': {'file_1': files[0]},
                 **checks}

        return self.send_return(sends, self.solver.rotate, files=files[:1])



    def test_files_list(self):
        
        sends = {'method': 'post', 'files': files_dict, **checks}
        return self.send_return(sends, self.solver.rotate, files=files)



    def test_files_dict(self):
        
        sends = {'method': 'post', 'files': files_dict, **checks}
        return self.send_return(sends, self.solver.rotate, files=files_dict)



    def test_all_params(self):
        
        params = {
                'angle'    : 40,
                'lang'     : 'en',
                'hintImg'  :  hint_img,
                'hintText' :	hint_text
                }


        sends = {
                'method'           : 'rotatecaptcha',
                'angle'            : 40,
                'lang'             : 'en',
                'textinstructions' : hint_text,
                'files'            : {'file': files[0],'imginstructions': hint_img},
                **checks
                }
        
        return self.send_return(sends, self.solver.rotate, file=files[0], **params)



    def test_not_found(self):

        return self.invalid_file(self.solver.rotate)



    def test_too_many(self):

        return self.too_many_files(self.solver.rotate)








if __name__ == '__main__':

    unittest.main()




import sys
import os
import requests
sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

from twocaptcha import TwoCaptcha

# in this example we store the API key inside environment variables that can be set like:
# export APIKEY_2CAPTCHA=1abc234de56fab7c89012d34e56fa7b8 on Linux or macOS
# set APIKEY_2CAPTCHA=1abc234de56fab7c89012d34e56fa7b8 on Windows
# you can just set the API key directly to it's value like:
# api_key="1abc234de56fab7c89012d34e56fa7b8"

api_key = os.getenv('APIKEY_2CAPTCHA', 'YOUR_API_KEY')

solver = TwoCaptcha(api_key, defaultTimeout=300, pollingInterval=10)

resp = requests.get("https://www.mysite.com/distil_r_captcha_challenge")
challenge = resp.content.decode('utf-8').split(';')[0]

try:
    result = solver.geetest(
        gt='f3bf6dbdcf7886856696502e1d55e00c',
        apiServer='api-na.geetest.com',
        challenge=challenge,
        url='https://www.mysite.com/distil_r_captcha.html',
        #  proxy={
        #      'type': 'HTTPS',
        #      'uri': 'login:password@IP_address:PORT'
        #  }
    )

except Exception as e:
    sys.exit(e)

else:
    sys.exit('result: ' + str(result))



import sys
import os

sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

from twocaptcha import TwoCaptcha

# in this example we store the API key inside environment variables that can be set like:
# export APIKEY_2CAPTCHA=1abc234de56fab7c89012d34e56fa7b8 on Linux or macOS
# set APIKEY_2CAPTCHA=1abc234de56fab7c89012d34e56fa7b8 on Windows
# you can just set the API key directly to it's value like:
# api_key="1abc234de56fab7c89012d34e56fa7b8"

api_key = os.getenv('APIKEY_2CAPTCHA', 'YOUR_API_KEY')

solver = TwoCaptcha(api_key)
!!!!
try:
    result = solver.keycaptcha(
        s_s_c_user_id=15,
        s_s_c_session_id='faa8cc1697c962ad4b859aa472f5d992',
        s_s_c_web_server_sign='4f84e4fe41cf688d8d94361489ecd75c-pz-',
        s_s_c_web_server_sign2='a9af97bb0a645eec495f2527e431a21b',
        url='https://www.keycaptcha.com/products/')

except Exception as e:
    sys.exit(e)

else:
    sys.exit('result: ' + str(result))



#!/usr/bin/env python3

import os, sys
import time
import requests

try:
    from .api import ApiClient

except ImportError:
    from api import ApiClient


class SolverExceptions(Exception):
    pass


class ValidationException(SolverExceptions):
    pass


class NetworkException(SolverExceptions):
    pass


class ApiException(SolverExceptions):
    pass


class TimeoutException(SolverExceptions):
    pass


class TwoCaptcha():
    def __init__(self,
                 apiKey,
                 softId=None,
                 callback=None,
                 defaultTimeout=120,
                 recaptchaTimeout=600,
                 pollingInterval=10,
                 server = '2captcha.com'):

        self.API_KEY = apiKey
        self.soft_id = softId
        self.callback = callback
        self.default_timeout = defaultTimeout
        self.recaptcha_timeout = recaptchaTimeout
        self.polling_interval = pollingInterval
        self.api_client = ApiClient(post_url = str(server))
        self.max_files = 9
        self.exceptions = SolverExceptions

    def normal(self, file, **kwargs):
        '''
        Wrapper for solving normal captcha (image)
        
        Required:
            file                (image, base64, or url)

        Optional params:

            phrase
            numeric
            minLen 
            maxLen 
            phrase 
            caseSensitive
            calc   
            lang
            hintText
            hintImg
            softId
            callback
            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
        '''

        method = self.get_method(file)
        result = self.solve(**method, **kwargs)
        return result

    def text(self, text, **kwargs):
        '''
        Wrapper for solving text captcha 

        Required:
            text
            
        Optional params:
            
            lang
            softId
            callback
        '''

        result = self.solve(text=text, method='post', **kwargs)
        return result

    def recaptcha(self, sitekey, url, version='v2', enterprise=0, **kwargs):
        '''
        Wrapper for solving recaptcha (v2, v3)

        Required:
            sitekey
            url

        Optional params:
            
            invisible
            version
            enterprise
            action
            score
            softId
            callback
            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
        '''

        params = {
            'googlekey': sitekey,
            'url': url,
            'method': 'userrecaptcha',
            'version': version,
            'enterprise': enterprise,
            **kwargs,
        }

        result = self.solve(timeout=self.recaptcha_timeout, **params)
        return result

    def funcaptcha(self, sitekey, url, **kwargs):
        '''
        Wrapper for solving funcaptcha

        Required:
            sitekey
            url

        Optional params:
            
            surl
            userAgent
            softId
            callback
            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
            **{'data[key]': 'anyStringValue'}
        '''

        result = self.solve(publickey=sitekey,
                            url=url,
                            method='funcaptcha',
                            **kwargs)
        return result

    def geetest(self, gt, challenge, url, **kwargs):
        '''
        Wrapper for solving geetest captcha

        Required:
            gt
            challenge
            url
                        
        Optional params:
            
            apiServer
            softId
            callback
            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
        '''

        result = self.solve(gt=gt,
                            challenge=challenge,
                            url=url,
                            method='geetest',
                            **kwargs)
        return result

    def hcaptcha(self, sitekey, url, **kwargs):
        '''
        Wrapper for solving hcaptcha

        Required:
            sitekey
            url

        Optional params:

            invisible
            data
            softId
            callback
            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
        '''

        result = self.solve(sitekey=sitekey,
                            url=url,
                            method='hcaptcha',
                            **kwargs)
        return result

    def keycaptcha(self, s_s_c_user_id, s_s_c_session_id,
                   s_s_c_web_server_sign, s_s_c_web_server_sign2, url,
                   **kwargs):
        '''
        Wrapper for solving 

        Required:
            s_s_c_user_id
            s_s_c_session_id
            s_s_c_web_server_sign
            s_s_c_web_server_sign2
            url

        Optional params:
            
            softId
            callback
            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
        '''

        params = {
            's_s_c_user_id': s_s_c_user_id,
            's_s_c_session_id': s_s_c_session_id,
            's_s_c_web_server_sign': s_s_c_web_server_sign,
            's_s_c_web_server_sign2': s_s_c_web_server_sign2,
            'url': url,
            'method': 'keycaptcha',
            **kwargs,
        }

        result = self.solve(**params)
        return result

    def capy(self, sitekey, url, **kwargs):
        '''
        Wrapper for solving capy

        Required:
            sitekey
            url

        Optional params:
            
            softId
            callback
            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
        '''

        result = self.solve(captchakey=sitekey,
                            url=url,
                            method='capy',
                            **kwargs)
        return result

    def grid(self, file, **kwargs):
        '''
        Wrapper for solving grid captcha (image)
        
        Required:
            file                (image or base64)

        Optional params:
            
            rows      
            cols      
            previousId
            canSkip   
            lang      
            hintImg   
            hintText  
            softId
            callback
            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
        '''

        method = self.get_method(file)

        params = {
            'recaptcha': 1,
            **method,
            **kwargs,
        }

        result = self.solve(**params)
        return result

    def canvas(self, file, **kwargs):
        '''
        Wrapper for solving canvas captcha (image)
        
        Required:
            file                (image or base64)

        Optional params:
            
            previousId
            canSkip   
            lang      
            hintImg   
            hintText  
            softId
            callback
            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
        '''

        if not ('hintText' in kwargs or 'hintImg' in kwargs):
            raise ValidationException(
                'parameters required: hintText and/or hintImg')

        method = self.get_method(file)

        params = {
            'recaptcha': 1,
            'canvas': 1,
            **method,
            **kwargs,
        }

        result = self.solve(**params)
        return result

    def coordinates(self, file, **kwargs):
        '''
        Wrapper for solving coordinates captcha (image)
        
        Required:
            file                (image or base64)

        Optional params:
            
            hintImg   
            hintText  
            lang
            softId
            callback
            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
        '''

        method = self.get_method(file)

        params = {
            'coordinatescaptcha': 1,
            **method,
            **kwargs,
        }

        result = self.solve(**params)
        return result

    def rotate(self, files, **kwargs):
        '''
        Wrapper for solving rotate captcha (image)
        
        Required:
            files               (images)

        Optional params:
            
            angle
            lang
            hintImg   
            hintText  
            softId
            callback
            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
        '''

        if isinstance(files, str):

            file = self.get_method(files)['file']

            result = self.solve(file=file, method='rotatecaptcha', **kwargs)
            return result

        elif isinstance(files, dict):
            files = list(files.values())

        files = self.extract_files(files)

        result = self.solve(files=files, method='rotatecaptcha', **kwargs)
        return result

    def solve(self, timeout=0, polling_interval=0, **kwargs):
        '''
        sends captcha, receives result


        Parameters
        ----------
        timeout : float
        polling_interval : int

        **kwargs : all captcha params

        Returns
        -------
        result : string
        '''

        id_ = self.send(**kwargs)
        result = {'captchaId': id_}

        if self.callback is None:

            timeout = float(timeout or self.default_timeout)
            sleep = int(polling_interval or self.polling_interval)

            code = self.wait_result(id_, timeout, sleep)
            result.update({'code': code})

        return result

    def wait_result(self, id_, timeout, polling_interval):

        max_wait = time.time() + timeout

        while time.time() < max_wait:

            try:
                return self.get_result(id_)

            except NetworkException:

                time.sleep(polling_interval)

        raise TimeoutException(f'timeout {timeout} exceeded')

    def get_method(self, file):

        if not file:
            raise ValidationException('File required')

        if not '.' in file and len(file) > 50:
            return {'method': 'base64', 'body': file}
        
        if file.startswith('http'):
            img_resp = requests.get(file)
            if img_resp.status_code != 200:
                raise ValidationException(f'File could not be downloaded from url: {file}')
            return {'method': 'base64', 'body': b64encode(img_resp.content).decode('utf-8')}

        if not os.path.exists(file):
            raise ValidationException(f'File not found: {file}')

        return {'method': 'post', 'file': file}

    def send(self, **kwargs):

        params = self.default_params(kwargs)
        params = self.rename_params(params)

        params, files = self.check_hint_img(params)

        response = self.api_client.in_(files=files, **params)

        if not response.startswith('OK|'):
            raise ApiException(f'cannot recognize response {response}')

        return response[3:]

    def get_result(self, id_):

        response = self.api_client.res(key=self.API_KEY, action='get', id=id_)

        if response == 'CAPCHA_NOT_READY':
            raise NetworkException

        if not response.startswith('OK|'):
            raise ApiException(f'cannot recognize response {response}')

        return response[3:]

    def balance(self):
        '''
        get my balance

        Returns
        -------
        balance : float

        '''

        response = self.api_client.res(key=self.API_KEY, action='getbalance')
        return float(response)

    def report(self, id_, correct):
        '''
        report of solved captcha: good/bad

        Parameters
        ----------
        id_ : captcha ID
        correct : True/False

        Returns
        -------
        None.

        '''

        rep = 'reportgood' if correct else 'reportbad'
        self.api_client.res(key=self.API_KEY, action=rep, id=id_)

        return

    def rename_params(self, params):

        replace = {
            'caseSensitive': 'regsense',
            'minLen': 'min_len',
            'maxLen': 'max_len',
            'hintText': 'textinstructions',
            'hintImg': 'imginstructions',
            'url': 'pageurl',
            'score': 'min_score',
            'text': 'textcaptcha',
            'rows': 'recaptcharows',
            'cols': 'recaptchacols',
            'previousId': 'previousID',
            'canSkip': 'can_no_answer',
            'apiServer': 'api_server',
            'softId': 'soft_id',
            'callback': 'pingback',
        }

        new_params = {
            v: params.pop(k)
            for k, v in replace.items() if k in params
        }

        proxy = params.pop('proxy', '')
        proxy and new_params.update({
            'proxy': proxy['uri'],
            'proxytype': proxy['type']
        })

        new_params.update(params)

        return new_params

    def default_params(self, params):

        params.update({'key': self.API_KEY})

        callback = params.pop('callback', self.callback)
        soft_id = params.pop('softId', self.soft_id)

        if callback: params.update({'callback': callback})
        if soft_id: params.update({'softId': soft_id})

        self.has_callback = bool(callback)

        return params

    def extract_files(self, files):

        if len(files) > self.max_files:
            raise ValidationException(
                f'Too many files (max: {self.max_files})')

        not_exists = [f for f in files if not (os.path.exists(f))]

        if not_exists:
            raise ValidationException(f'File not found: {not_exists}')

        files = {f'file_{e+1}': f for e, f in enumerate(files)}
        return files

    def check_hint_img(self, params):

        hint = params.pop('imginstructions', None)
        files = params.pop('files', {})

        if not hint:
            return params, files

        if not '.' in hint and len(hint) > 50:
            return params, files

        if not os.path.exists(hint):
            raise ValidationException(f'File not found: {hint}')

        if not files:
            files = {'file': params.pop('file', {})}

        files.update({'imginstructions': hint})

        return params, files


if __name__ == '__main__':

    key = sys.argv[1]
    sol = TwoCaptcha(key)



#!/usr/bin/env python3

import unittest

file = '../examples/images/normal.jpg'
hint_img = '../examples/images/grid_hint.jpg'


try:
    from .abstract import AbstractTest

    file = file[3:]
    hint_img = hint_img[3:]
    
except ImportError:
    from abstract import AbstractTest




class NormalTest(AbstractTest):
    
    def test_file(self):
        
        sends = {'method': 'post', 'file': file}
        return self.send_return(sends, self.solver.normal, file=file)



    # def test_file_params(self):
        
    #     return self.test_send_return(self.method, self.file, method='post')



    def test_base64(self):
        
        b64 = 'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
        sends = {
                'method': 'base64',
                'body'  : b64,
                }

        return self.send_return(sends, self.solver.normal, file=b64)



    def test_all_params(self):

        
        params = {
                'numeric'       : 4,
                'minLen'        : 4,
                'maxLen'        : 20,
                'phrase'        : 1,
                'caseSensitive' : 1,
                'calc'          : 0,
                'lang'          : 'en',
                'hintImg'       : hint_img,
                'hintText'      : 'Type red symbols only',
                }


        sends = {
                'files'            : {'file': file,'imginstructions': hint_img},
                'method'           : 'post',
                'numeric'          : 4,
                'min_len'          : 4,
                'max_len'          : 20,
                'phrase'           : 1,
                'regsense'         : 1,
                'calc'             : 0,
                'lang'             : 'en',
                'textinstructions' : 'Type red symbols only',
                }

        # files = {
        #         'file'            : file,
        #         'imginstructions' : hint,
        #         }

        return self.send_return(sends, self.solver.normal, file=file, **params)



    def test_not_found(self):

        return self.invalid_file(self.solver.normal)










if __name__ == '__main__':

    unittest.main()




import sys
'../../' in sys.path or sys.path.append('../../../')

from twocaptcha import TwoCaptcha



sol = TwoCaptcha('YOUR_API_KEY', defaultTimeout=120)


try:
    result = sol.keycaptcha(s_s_c_user_id          = 10,
                            s_s_c_session_id       = '493e52c37c10c2bcdf4a00cbc9ccd1e8',
                            s_s_c_web_server_sign  = '9006dc725760858e4c0715b835472f22-pz-',
                            s_s_c_web_server_sign2 = '2ca3abe86d90c6142d5571db98af6714',
                            url                    = 'https://www.keycaptcha.ru/demo-magnetic/', 
                            proxy                  = {
                                                      'type': 'HTTPS',
                                                      'uri': 'login:password@IP_address:PORT'})

        
except Exception as e:
    sys.exit(e)
    
else:
    sys.exit('result: ' + str(result))

    


import sys
import os
from base64 import b64encode

sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

from twocaptcha import TwoCaptcha

# in this example we store the API key inside environment variables that can be set like:
# export APIKEY_2CAPTCHA=1abc234de56fab7c89012d34e56fa7b8 on Linux or macOS
# set APIKEY_2CAPTCHA=1abc234de56fab7c89012d34e56fa7b8 on Windows
# you can just set the API key directly to it's value like:
# api_key="1abc234de56fab7c89012d34e56fa7b8"

api_key = os.getenv('APIKEY_2CAPTCHA', 'YOUR_API_KEY')

solver = TwoCaptcha(api_key)

with open('images/grid.jpg', 'rb') as f:
    b64 = b64encode(f.read()).decode('utf-8')

try:
    result = solver.coordinates(b64)

except Exception as e:
    sys.exit(e)

else:
    sys.exit('result: ' + str(result))



#!/usr/bin/env python3

import unittest

try:
    from .abstract import AbstractTest
except ImportError:
    from abstract import AbstractTest



class FuncaptchaTest(AbstractTest):
    

    def test_all_params(self):
        
        
        params = {
                'sitekey'   : '69A21A01-CC7B-B9C6-0F9A-E7FA06677FFC',
                'url'       : 'https://mysite.com/page/with/funcaptcha',
                'surl'      : 'https://client-api.arkoselabs.com',
                'userAgent' : 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.61 Safari/537.36',
                'data'      : {'anyKey' : 'anyStringValue'},
                }
        
        sends = {
                'method'    : 'funcaptcha',
                'publickey' : '69A21A01-CC7B-B9C6-0F9A-E7FA06677FFC',
                'pageurl'   : 'https://mysite.com/page/with/funcaptcha',
                'surl'      : 'https://client-api.arkoselabs.com',
                'userAgent' : 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.61 Safari/537.36',
                'data'      : {'anyKey' : 'anyStringValue'},
                }

        return self.send_return(sends, self.solver.funcaptcha, **params)





if __name__ == '__main__':

    unittest.main()




#!/usr/bin/env python3

import unittest

try:
    from .abstract import AbstractTest
except ImportError:
    from abstract import AbstractTest



class CapyTest(AbstractTest):
    

    def test_all_params(self):
        
        
        params = {
                 'sitekey' : 'PUZZLE_Abc1dEFghIJKLM2no34P56q7rStu8v',
                 'url'     : 'http://mysite.com/',
                }
        
        sends = {
                'method'     : 'capy',
                'captchakey' : 'PUZZLE_Abc1dEFghIJKLM2no34P56q7rStu8v',
                'pageurl'    : 'http://mysite.com/',
                }

        return self.send_return(sends, self.solver.capy, **params)





if __name__ == '__main__':

    unittest.main()




#!/usr/bin/env python3

import unittest

try:
    from .abstract import AbstractTest
except ImportError:
    from abstract import AbstractTest



class HcaptchaTest(AbstractTest):
    

    def test_all_params(self):
        
        
        params = {
                'sitekey' : 'f1ab2cdefa3456789012345b6c78d90e',
                'url'     : 'https://www.site.com/page/',
                }
        
        sends = {
                'method'  : 'hcaptcha',
                'sitekey' : 'f1ab2cdefa3456789012345b6c78d90e',
                'pageurl' : 'https://www.site.com/page/',
                }

        return self.send_return(sends, self.solver.hcaptcha, **params)





if __name__ == '__main__':

    unittest.main()




#!/usr/bin/env python3

import unittest

try:
    from .abstract import AbstractTest
except ImportError:
    from abstract import AbstractTest



class RecaptchaTest(AbstractTest):
    

    def test_v2(self):
        
        params = {
                'sitekey'   : '6Le-wvkSVVABCPBMRTvw0Q4Muexq1bi0DJwx_mJ-',
                'url'       : 'https://mysite.com/page/with/recaptcha',
                'invisible' :  1,
                'action'    : 'verify',
                }
        
        sends = {
                'method'    : 'userrecaptcha',
                'googlekey' : '6Le-wvkSVVABCPBMRTvw0Q4Muexq1bi0DJwx_mJ-',
                'pageurl'   : 'https://mysite.com/page/with/recaptcha',
                'invisible': 1,
                'enterprise': 0,                
                'action'    : 'verify',
                'version'   : 'v2',
                }

        return self.send_return(sends, self.solver.recaptcha, **params)


    def test_v3(self):
        
        params = {
                'sitekey'   : '6Le-wvkSVVABCPBMRTvw0Q4Muexq1bi0DJwx_mJ-',
                'url'       : 'https://mysite.com/page/with/recaptcha',
                'invisible' :  1,
                'action'    : 'verify',
                'version'   : 'v3',
                }
        
        sends = {
                'method'    : 'userrecaptcha',
                'googlekey' : '6Le-wvkSVVABCPBMRTvw0Q4Muexq1bi0DJwx_mJ-',
                'pageurl'   : 'https://mysite.com/page/with/recaptcha',
                'invisible' : 1,
                'enterprise': 0,
                'action'    : 'verify',
                'version'   : 'v3',
                }

        return self.send_return(sends, self.solver.recaptcha, **params)



if __name__ == '__main__':

    unittest.main()




#!/usr/bin/env python3

import unittest

from abstract import AbstractTest

file = '../examples/images/canvas.jpg'
hint = 'Draw around apple'

checks = {'canvas': 1, 'recaptcha': 1, 'textinstructions': hint}


class CanvasTest(AbstractTest):
    def test_file_param(self):

        sends = {'method': 'post', 'file': file, **checks}
        return self.send_return(sends,
                                self.solver.canvas,
                                file=file,
                                hintText=hint)

    def test_base64_param(self):

        b64 = 'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
        sends = {
            'method': 'base64',
            'body': b64,
            **checks,
        }

        return self.send_return(sends,
                                self.solver.canvas,
                                file=b64,
                                hintText=hint)

    def test_all_params(self):

        hint_img = '../examples/images/canvas_hint.jpg'

        params = {
            'previousId': 0,
            'canSkip': 0,
            'lang': 'en',
            'hintImg': hint_img,
            'hintText': hint
        }

        sends = {
            'method': 'post',
            'previousID': 0,
            'can_no_answer': 0,
            'lang': 'en',
            'files': {
                'file': file,
                'imginstructions': hint_img
            },
            **checks
        }

        return self.send_return(sends, self.solver.canvas, file=file, **params)

    def test_not_found(self):

        return self.invalid_file(self.solver.canvas, hintText=hint)


if __name__ == '__main__':

    unittest.main()



import sys
import os

sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

from twocaptcha import TwoCaptcha

# in this example we store the API key inside environment variables that can be set like:
# export APIKEY_2CAPTCHA=1abc234de56fab7c89012d34e56fa7b8 on Linux or macOS
# set APIKEY_2CAPTCHA=1abc234de56fab7c89012d34e56fa7b8 on Windows
# you can just set the API key directly to it's value like:
# api_key="1abc234de56fab7c89012d34e56fa7b8"

api_key = os.getenv('APIKEY_2CAPTCHA', 'YOUR_API_KEY')


config = {
            'server':           '2captcha.com', # can be also set to 'rucaptcha.com'
    		'apiKey':           api_key,
    		'softId':            123,
    		# 'callback':         'https://your.site/result-receiver', # if set, sovler with just return captchaId, not polling API for the answer
    		'defaultTimeout':    120,
    		'recaptchaTimeout':  600,
    		'pollingInterval':   10,
	    }

solver = TwoCaptcha(**config)

try:
    result = solver.hcaptcha(sitekey='3ceb8624-1970-4e6b-91d5-70317b70b651',
                             url='https://2captcha.com/demo/hcaptcha?difficulty=easy',
                            #  proxy={
                                #  'type': 'HTTPS',
                                #  'uri': 'login:password@IP_address:PORT'
                            #  }
                            )

except Exception as e:
    sys.exit(e)

else:
    sys.exit('result: ' + str(result))



#!/usr/bin/env python3
import unittest
import sys
import os

sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

from twocaptcha import TwoCaptcha

captcha_id = '123'
code = 'abcd'


class ApiClient():
    def in_(self, files={}, **kwargs):

        self.incomings = kwargs
        self.incoming_files = files

        return 'OK|' + captcha_id

    def res(self, **kwargs):

        return 'OK|' + code  # {'code': code}


class AbstractTest(unittest.TestCase):
    def setUp(self):

        self.solver = TwoCaptcha('API_KEY', pollingInterval=1)
        self.solver.api_client = ApiClient()

    def send_return(self, for_send, method, **kwargs):

        file = kwargs.pop('file', {})
        file = kwargs.pop('files', file)

        result = method(file, **kwargs) if file else method(**kwargs)

        incomings = self.solver.api_client.incomings
        for_send.update({'key': 'API_KEY'})

        files = for_send.pop('files', {})
        self.assertEqual(incomings, for_send)

        incoming_files = self.solver.api_client.incoming_files
        incoming_files and self.assertEqual(incoming_files, files)

        self.assertIsInstance(result, dict)
        self.assertIn('code', result)
        self.assertEqual(result['code'], code)

    def invalid_file(self, method, **kwargs):

        self.assertRaises(self.solver.exceptions, method, 'lost_file',
                          **kwargs)

    def too_many_files(self, method, **kwargs):

        files = ['../examples/images/rotate.jpg'] * (self.solver.max_files + 1)
        self.assertRaises(self.solver.exceptions, method, files, **kwargs)


if __name__ == '__main__':

    unittest.main()



import sys
import os
sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

from twocaptcha import TwoCaptcha

# in this example we store the API key inside environment variables that can be set like:
# export APIKEY_2CAPTCHA=1abc234de56fab7c89012d34e56fa7b8 on Linux or macOS
# set APIKEY_2CAPTCHA=1abc234de56fab7c89012d34e56fa7b8 on Windows
# you can just set the API key directly to it's value like:
# api_key="1abc234de56fab7c89012d34e56fa7b8"

api_key = os.getenv('APIKEY_2CAPTCHA', 'YOUR_API_KEY')

solver = TwoCaptcha(api_key, defaultTimeout=180, pollingInterval=15)

try:
    result = solver.funcaptcha(
        sitekey='FB18D9DB-BAFF-DDAC-A33B-6CF22267BC0A',
        url='https://mysite.com/page/with/funcaptcha',
        surl='https://client-api.arkoselabs.com',
        userAgent=
        'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.61 Safari/537.36',
        **{'data[key]': 'value'},  #optional data param used by some websites
        proxy={
            'type': 'HTTP',
            'uri': 'login:password@123.123.123.123:8080'
        })

except Exception as e:
    sys.exit(e)

else:
    sys.exit('result: ' + str(result))
